Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1116)

Unified Diff: mojo/services/view_manager/default_access_policy.cc

Issue 534843002: Convert view manager to surfaces with uploading shim in client lib (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: remove overzealous shutdown check in cc/surfaces, add NON_EXPORTED_BASE for windows build, saturate… Created 6 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/services/view_manager/default_access_policy.h ('k') | mojo/services/view_manager/display_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/services/view_manager/default_access_policy.cc
diff --git a/mojo/services/view_manager/default_access_policy.cc b/mojo/services/view_manager/default_access_policy.cc
index 525e76eb6a096bb5ff21e5a3b40e550cbf3f31f9..a2443c3d432e7df0fc31fa34c029e11e19a11c73 100644
--- a/mojo/services/view_manager/default_access_policy.cc
+++ b/mojo/services/view_manager/default_access_policy.cc
@@ -66,9 +66,9 @@ bool DefaultAccessPolicy::CanChangeViewVisibility(
return WasCreatedByThisConnection(view) || IsViewInRoots(view);
}
-bool DefaultAccessPolicy::CanSetViewContents(const ServerView* view) const {
+bool DefaultAccessPolicy::CanSetViewSurfaceId(const ServerView* view) const {
// Once a view embeds another app, the embedder app is no longer able to
// call SetViewContents() - this ability is transferred to the embedded app.
if (delegate_->IsViewRootOfAnotherConnectionForAccessPolicy(view))
return false;
return WasCreatedByThisConnection(view) || IsViewInRoots(view);
@@ -66,9 +66,9 @@ bool DefaultAccessPolicy::CanChangeViewVisibility(
// Once a view embeds another app, the embedder app is no longer able to
- // call SetViewContents() - this ability is transferred to the embedded app.
+ // call SetViewSurfaceId() - this ability is transferred to the embedded app.
if (delegate_->IsViewRootOfAnotherConnectionForAccessPolicy(view))
return false;
« no previous file with comments | « mojo/services/view_manager/default_access_policy.h ('k') | mojo/services/view_manager/display_manager.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698